PosClient class

Implemented types
Mixed-in types

Constructors

PosClient({required String projectId, required String deviceId, required Metadata metadata, int? maxCheckAttempts, LogLevel logLevel = LogLevel.all})

Properties

configuredTokens → List<PosToken>
ℹ️ When you call setTokens with your supported tokens a filtering will be applied over WalletConnect API supported networks So some tokens could end up to be not supported. This list is the result of that check.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
onPosEvent → Event<PosEvent>
ℹ️ Subscription to POS events: QrReadyEvent, ConnectedEvent, ConnectRejectedEvent, ConnectFailedEvent, PaymentRequestedEvent, PaymentRequestRejectedEvent, PaymentRequestFailedEvent, PaymentBroadcastedEvent, PaymentSuccessfulEvent, PaymentFailedEvent, DisconnectedEvent
final
reOwnSign ↔ IReownSign?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPaymentIntent({required List<PaymentIntent> paymentIntents}) → Future<void>
ℹ️ Initiates the payment flow. Best practice is to wrap it with try/catch for any implementation error
override
init() → Future<void>
ℹ️ init the SDK
override
isValidPaymentIntents(PaymentIntent intent) → void
inherited
isValidSessionApproved(SessionData approvedSession, PaymentIntent intent) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
posBuildTransaction({required BuildTransactionParams params, required QueryParams queryParams}) → Future<JsonRpcResponse>
inherited
posCheckTransaction({required CheckTransactionParams params, required QueryParams queryParams}) → Future<JsonRpcResponse>
inherited
posSupportedNetworks({required QueryParams queryParams}) → Future<JsonRpcResponse>
inherited
restart({bool reinit = false}) → Future<void>
ℹ️ To be called when you want to abort an ongoing intent or restart the flow when a payment finished. With reinit = true will clear the instance meaning that init() and setTokens() will have to be called again
override
setTokens({required List<PosToken> tokens}) → void
ℹ️ configure available tokens on your POS app
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited