EvmTransactionParams class sealed

Available extensions
Annotations
  • @freezed

Constructors

EvmTransactionParams({required String from, required String to, required String value, String? gas, String? gasPrice, String? maxFeePerGas, String? maxPriorityFeePerGas, String? input, String? data})
const
factory
EvmTransactionParams.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $EvmTransactionParamsCopyWith<EvmTransactionParams>
Create a copy of EvmTransactionParams with the given fields replaced by the non-null parameter values.
no setterinherited
data → String?
no setterinherited
from → String
no setterinherited
gas → String?
no setterinherited
gasPrice → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
input → String?
no setterinherited
maxFeePerGas → String?
no setterinherited
maxPriorityFeePerGas → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → String
no setterinherited
value → String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EvmTransactionParams value)) → TResult

Available on EvmTransactionParams, provided by the EvmTransactionParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EvmTransactionParams value)?) → TResult?

Available on EvmTransactionParams, provided by the EvmTransactionParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EvmTransactionParams value)?, {required TResult orElse()}) → TResult

Available on EvmTransactionParams, provided by the EvmTransactionParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String from, String to, String value, String? gas, String? gasPrice, String? maxFeePerGas, String? maxPriorityFeePerGas, String? input, String? data)?, {required TResult orElse()}) → TResult

Available on EvmTransactionParams, provided by the EvmTransactionParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EvmTransactionParams to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String from, String to, String value, String? gas, String? gasPrice, String? maxFeePerGas, String? maxPriorityFeePerGas, String? input, String? data)) → TResult

Available on EvmTransactionParams, provided by the EvmTransactionParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String from, String to, String value, String? gas, String? gasPrice, String? maxFeePerGas, String? maxPriorityFeePerGas, String? input, String? data)?) → TResult?

Available on EvmTransactionParams, provided by the EvmTransactionParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited