PosApiError enum

Inheritance
Available extensions

Values

invalidAsset → const PosApiError
invalidRecipient → const PosApiError
invalidSender → const PosApiError
invalidAmount → const PosApiError
invalidAddress → const PosApiError
invalidWalletResponse → const PosApiError
invalidTransactionId → const PosApiError
failedToEstimateGas → const PosApiError
invalidProviderUrl → const PosApiError
rpcError → const PosApiError
internal → const PosApiError
invalidFormat → const PosApiError
invalidChainId → const PosApiError
insufficientFundsForTransfer → const PosApiError
transferAmountExceedsBalance → const PosApiError
broadcastFailed → const PosApiError
unknown → const PosApiError

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortMessage → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonRpcError(JsonRpcError error) → PosApiError

Constants

values → const List<PosApiError>
A constant List of the values in this enum, in order of their declaration.